﻿using DevExpress.ExpressApp;
using DevExpress.ExpressApp.Actions;
using System;
using Xafari.Data;

namespace ImportDataFromExcel.Module.Win.Controllers
{
	public class ImportExportDataViewController : ViewController
	{
		SimpleAction exporDataSimpleAction;
		SimpleAction importDataSimpleAction;

		public ImportExportDataViewController()
		{
			this.exporDataSimpleAction = new SimpleAction(this, "ExportDataToExcel", DevExpress.Persistent.Base.PredefinedCategory.Edit);
			this.exporDataSimpleAction.Execute += this.ExporDataSimpleAction_Execute;

			this.importDataSimpleAction = new SimpleAction(this, "ImportDataFromExcel", DevExpress.Persistent.Base.PredefinedCategory.Edit);
			this.importDataSimpleAction.Execute += this.ImportDataSimpleAction_Execute;
		}

		private void ImportDataSimpleAction_Execute(object sender, SimpleActionExecuteEventArgs e)
		{
			var settingsFile = $"{Environment.CurrentDirectory}\\ImportExportData\\Demo_ImportSettings.xml";
			var settings = ImportSettings.LoadFromXml(settingsFile);

			var dataSource = new ExcelDataSource();
			dataSource.SourcePath = $"{Environment.CurrentDirectory}\\ImportExportData\\TestImportExcel.xls";
			var operation = new ImportOperation(this.Application);
			operation.DataSource = dataSource;
			operation.Settings = settings;
			using (var objectSpace = this.Application.CreateObjectSpace())
			{
				operation.Execute();
			}
		}

		private void ExporDataSimpleAction_Execute(object sender, SimpleActionExecuteEventArgs e)
		{
			//1. Load Export Settings
			var settingsFile = $"{Environment.CurrentDirectory}\\ImportExportData\\Demo_ExportSettings.xml";
			var settings = ExportSettings.LoadFromXml(settingsFile);

			// 2. Create DataSource

			var dataSource = new ExcelDataSource();
			dataSource.DestinationPath = "ImportExportData\\ExcelExport.xls";

			// 3. Execute Export Operation using ExportSettings and DataSource
			var operation = new ExportOperation(this.Application);
			operation.DataSource = dataSource;
			operation.Settings = settings;
			using (var objectSpace = this.Application.CreateObjectSpace())
			{
				operation.Execute();
			}
		}
	}
}
